@@ -283,21 +283,24 @@ static void shift_left(chunk_group_t * cg){
         cg->nextfc = tempfc;
 }
 
-static float valuehelper(filechunk_t* fc, int channel, long index){
+static float valuehelper(filechunk_t* fc, int channel, double index){
 	if (filechunk_get_priority(fc) == DS_PRIORITY_RELAXED){
 		struct timeval tv;
 		long l = 0;
 		while (((filechunk_get_done(fc) + filechunk_get_start(fc)) 
-			< index) && (l++ < 1000)){
+			< index) && (l++ < 10 /* was 1000 */)){
 /*				printf ("sleepwait\n");*/
                                 tv.tv_sec = 0;
-                                tv.tv_usec = 100;
+                                tv.tv_usec = 10000; /* was 100*/
                                 select(0, NULL, NULL, NULL, &tv);
                 }
 	}
-	if (channel == 1)
+	if (filechunk_get_length (fc) < 1 ) return 0.0;
+	if (channel == 1){
         	return inter4pol_float(fc->L, index - filechunk_get_start(fc), filechunk_get_done(fc));
-        else    return inter4pol_float(fc->R, index - filechunk_get_start(fc), filechunk_get_done(fc));
+        } else {    
+		return inter4pol_float(fc->R, index - filechunk_get_start(fc), filechunk_get_done(fc));
+	}
 }
 
 static long wrapindex (long index, long start, long end){
@@ -308,12 +311,13 @@ static long wrapindex (long index, long start, long end){
 	return index; 
 }
 
-float buffer_readsample_interpolated(buffer_info_t* buf, int channel, float index, int group){
+float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double index, int group){
 	if (!buf) return 0.;
 	if (!buf->chunk_list) return 0;
 	if (!buf->chunk_list[group]) return 0;
 
-	index *= buf->samplerate_factor;
+	index *=  buf->samplerate_factor;
+	double dindex = index;
 
 	if (buf->type == BUFFER_TYPE_DISCSTREAM){ 
 		if (buf->group_max < group) return 0;
@@ -465,13 +469,16 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, float inde
 	} else {
 		/* LATER: wrap interpolation around loopborders */
 		/* this is quite expensive: */
-		if (channel == 1)
+		if (filechunk_get_length (buf->chunk_list[group]->readfc) < 1) return 0.0;
+		if (channel == 1){ 
 			return inter4pol_float(buf->chunk_list[group]->readfc->L,
-					index,(double)buffer_get_size(buf) * (double)buf->samplerate_factor) 
+					dindex,(double)buffer_get_size(buf) * (double)buf->samplerate_factor) 
 				* buf->volume_factor;
-		else 	return inter4pol_float(buf->chunk_list[group]->readfc->R,
-					index,(double)buffer_get_size(buf) * (double)buf->samplerate_factor) 
+		} else { 	
+			return inter4pol_float(buf->chunk_list[group]->readfc->R,
+					dindex,(double)buffer_get_size(buf) * (double)buf->samplerate_factor) 
 				* buf->volume_factor;
+		}
 	}
 	return 0.;
 }
@@ -532,9 +539,10 @@ float buffer_analyze(buffer_info_t* buf, int gid, long start,long end){
 			val = fabs(buffer_readsample_interpolated(buf,2,(float)l,group) / buf->volume_factor);
 			if (val > max) max = val;
 		}
-		if (!(l % 100000)){
+		if (!(l % 1000000)){
+/*			printf ("normalize:%ld\n",l);*/
 			tv.tv_sec = 0;
-			tv.tv_usec = 1000;
+			tv.tv_usec = 100;
 			select(0, NULL, NULL, NULL, &tv);
 		}
 	}
@@ -780,7 +788,7 @@ static void* buffer_discthread(void *ptr){
 
 		if (!dirty){
 	        	tv.tv_sec = 0;
-        		tv.tv_usec = 100000; /* max 10 times a sec */
+        		tv.tv_usec = 10000; /* max 100 times a sec */
 			select(0, NULL, NULL, NULL, &tv);
 		}
 	}
