@@ -93,7 +93,7 @@ looper_data_t* looperdata_new(buffer_info_t* buf, long samplerate,int id){
 		*(data->customplaymode + i) = 1.;
 	}
 
-	data->midichannel = -1; 
+	data->midichannel = 0; 
 	data->ngrains = 0;
 	data->grainmixfactor = 1.;
 	data->mingrainspeed = 1.;
@@ -461,13 +461,13 @@ float looperdata_get_recmix(looper_data_t* data){
 }
 
 int looperdata_get_midichannel (looper_data_t* data){
-	/* muse and my keyboard send 0 when they write 1 ?!? */
+	/* muse and my keyboard send 0 when they say 1 ?!? */
 	return (data->midichannel - 1);
 }
 
 void looperdata_set_midichannel (looper_data_t* data, int channel){
 	if ((channel > -1) && (channel < 16))
-		data->midichannel = channel;
+		data->midichannel = channel + 1;
 	else	data->midichannel = -1;
 }
 
